# Changelog

**1.1.2** (2025-10-09)
  * Maintenance updates via ambient-package-update

**1.1.1** (2025-10-09)
  * Maintenance updates via ambient-package-update

**1.1.0** (2025-10-08)
  * Added known deprecations for `FORMS_URLFIELD_ASSUME_HTTPS` and `URLIZE_ASSUME_HTTPS`

**1.0.9** (2025-06-05)
  * Fixed issue of wrong deprecation version for `SECURE_BROWSER_XSS_FILTER`

**1.0.8** (2025-05-29)
  * Maintenance updates via ambient-package-update

**1.0.7** (2025-04-03)
  * Maintenance updates via ambient-package-update

**1.0.6** (2025-02-15)
  * Maintenance updates via ambient-package-update

**1.0.5** (2024-11-28)
   * Fixed display bug with two-digit Django versions

**1.0.4** (2024-11-20)
   * Improved docs

**1.0.3** (2024-11-19)
   * Added screenshot to documentation for clarification

**1.0.2** (2024-11-19)
   * Moved `DEFAULT_FILE_STORAGE` removal from Django 3.1 to Django 5.1

**1.0.1** (2024-11-19)
   * Added docs at RTD

**1.0.0** (2024-11-19)
   * Added system checks for all known setting variable removals since Django v1.0
